@@ -9,7 +9,7 @@ JsonData = Union[
     Dict[JsonScalar, Union[JsonScalar, ForwardRef('JsonData')]]
 ]
 
-ID_STRING = r'[0-9a-fA-F]{24}'
+ID_STRING = r'^[0-9a-fA-F]{24}$'
 
 
 class RangeBorderCrossing(PydanticValueError):
